@@ -145,7 +145,9 @@ class BaseKempAppliance(HttpClient, AccessInfoMixin):
         :param command:
         :return:
         """
-        curl = ['curl', '-s', '-k', '--connect-timeout', str(utils.TIMEOUT)]
+        curl = [
+            'curl', '-f', '-s', '-k', '--connect-timeout', str(utils.TIMEOUT)
+        ]
         command = '{}/{}'.format(self.endpoint, command)
         if self.cert:
             curl.extend(['-E', self.cert])
@@ -402,13 +404,20 @@ class BaseKempAppliance(HttpClient, AccessInfoMixin):
     def download_user_cert(self, user, location=os.curdir):
         file_name = os.path.join(location, "{}.cert".format(user))
 
-        with open(file_name, 'wb') as file:
-            cmd = self._get_curl_command_list('userdownloadcert?user={}'
-                                              .format(user))
-            subprocess.call(cmd, stdout=file)
-            file.seek(0, 2)
-            if file.tell() == 0:
-                raise DownloadUserCertFailed(self.ip_address)
+        #with open(file_name, 'wb') as file:
+        file = open(file_name, 'wb')
+        cmd = self._get_curl_command_list('userdownloadcert?user={}'
+                                          .format(user))
+        ret = subprocess.call(cmd, stdout=file)
+        if ret != 0:
+            # If the command did not succeed, remove the file
+            file.close()
+            os.remove(file.name)
+            raise DownloadUserCertFailed(self.ip_address)
+        file.seek(0, 2)
+        if file.tell() == 0:
+            file.close()
+            raise DownloadUserCertFailed(self.ip_address)
         return file_name
 
     def restore_cert(self, password, file, restore_type="full"):
@@ -448,12 +457,20 @@ class BaseKempAppliance(HttpClient, AccessInfoMixin):
         file_name = os.path.join(location, "{}_{}.backup".format(
             self.ip_address, time.strftime("%Y-%m-%d_%H:%M:%S")))
 
-        with open(file_name, 'wb') as file:
-            cmd = self._get_curl_command_list('backup')
-            subprocess.call(cmd, stdout=file)
-            file.seek(0, 2)
-            if file.tell() == 0:
-                raise BackupFailed(self.ip_address)
+        #with open(file_name, 'wb') as file:
+        file = open(file_name, 'wb')
+        cmd = self._get_curl_command_list('backup')
+        ret = subprocess.call(cmd, stdout=file)
+        if ret != 0:
+            # If the command did not succeed, remove the file
+            file.close()
+            os.remove(file.name)
+            raise BackupFailed(self.ip_address)
+        file.seek(0, 2)
+        if file.tell() == 0:
+            file.close()
+            raise BackupFailed(self.ip_address)
+        file.close()
         return file_name
 
     def restore_backup(self, backup_type, file):
@@ -1366,16 +1383,23 @@ class LoadMaster(BaseKempAppliance):
             file_name = os.path.join(location, "{}_{}.backup".format(
                 self.ip_address, time.strftime("%Y-%m-%d_%H:%M:%S")))
 
-        with open(file_name, 'wb') as file:
-            cmd = self._get_curl_command_list(
-                'backupcert?{}'.format(
-                    urlencoder.urlencode({"password": password})
-                )
+        #with open(file_name, 'wb') as file:
+        file = open(file_name, 'wb')
+        cmd = self._get_curl_command_list(
+            'backupcert?{}'.format(
+                urlencoder.urlencode({"password": password})
             )
-            subprocess.call(cmd, stdout=file)
-            file.seek(0, 2)
-            if file.tell() == 0:
-                raise BackupFailed(self.ip_address)
+        )
+        ret = subprocess.call(cmd, stdout=file)
+        if ret != 0:
+            # If the command did not succeed, remove the file
+            file.close()
+            os.remove(file.name)
+            raise BackupFailed(self.ip_address)
+        file.seek(0, 2)
+        if file.tell() == 0:
+            file.close()
+            raise BackupFailed(self.ip_address)
 
         return file_name
 
